WhisperModelConfig class

Model initialization options.

Annotations

Constructors

WhisperModelConfig({bool useGpu = true, bool flashAttention = true, int gpuDevice = 0})
const
WhisperModelConfig.forDevice(WhisperDevice device, {bool flashAttention = true})
factory

Properties

flashAttention bool
final
gpuDevice int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useGpu bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited