WhisperModelManager class abstract final

Downloads and caches official GGML models on native platforms.

On Web, prepare returns the remote URL. The WebAssembly worker downloads the model while FlutterWhisper.loadModel reports onModelProgress.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

prepare(WhisperModel model, {String? directoryPath, bool forceDownload = false, WhisperModelDownloadCallback? onProgress}) Future<String>