WhisperToken class

Annotations

Constructors

WhisperToken({required int id, required String text, required double probability, required Duration start, required Duration end})
const

Properties

end Duration
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
probability double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start Duration
final
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited