WhisperModel class final
Metadata for a downloadable whisper.cpp GGML model.
- Annotations
Constructors
- WhisperModel({required String id, required int sizeBytes, required String sha256, String baseUrl = WhisperModels.defaultBaseUrl})
-
const
Properties
- baseUrl → String
-
Repository directory containing fileName.
final
- downloadUri → Uri
-
no setter
- fileName → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Model identifier used by the official whisper.cpp download scripts.
final
- isEnglishOnly → bool
-
no setter
- isQuantized → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sha256 → String
-
SHA-256 digest published by the model repository.
final
- sizeBytes → int
-
Exact size of the current official model file.
final
- sizeLabel → String
-
no setter
- supportsTinyDiarize → bool
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited