WhisperModelDownloadProgress class final
- Annotations
Constructors
- WhisperModelDownloadProgress({required int receivedBytes, required int totalBytes})
-
const
Properties
- fraction → double
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- percent → int
-
no setter
- receivedBytes → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalBytes → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited