Models offered by the official whisper.cpp v1.9.2 download scripts.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
byId(
String id) → WhisperModel?
Constants
- base → const WhisperModel
- baseEn → const WhisperModel
- baseEnQ5_1 → const WhisperModel
- baseEnQ8_0 → const WhisperModel
- baseQ5_1 → const WhisperModel
- baseQ8_0 → const WhisperModel
- defaultBaseUrl → const String
- largeV1 → const WhisperModel
- largeV2 → const WhisperModel
- largeV2Q5_0 → const WhisperModel
- largeV2Q8_0 → const WhisperModel
- largeV3 → const WhisperModel
- largeV3Q5_0 → const WhisperModel
- largeV3Turbo → const WhisperModel
- largeV3TurboQ5_0 → const WhisperModel
- largeV3TurboQ8_0 → const WhisperModel
- medium → const WhisperModel
- mediumEn → const WhisperModel
- mediumEnQ5_0 → const WhisperModel
- mediumEnQ8_0 → const WhisperModel
- mediumQ5_0 → const WhisperModel
- mediumQ8_0 → const WhisperModel
- small → const WhisperModel
- smallEn → const WhisperModel
- smallEnQ5_1 → const WhisperModel
- smallEnQ8_0 → const WhisperModel
- smallEnTinyDiarize → const WhisperModel
- smallQ5_1 → const WhisperModel
- smallQ8_0 → const WhisperModel
- tiny → const WhisperModel
- tinyDiarizeBaseUrl → const String
- tinyEn → const WhisperModel
- tinyEnQ5_1 → const WhisperModel
- tinyEnQ8_0 → const WhisperModel
- tinyQ5_1 → const WhisperModel
- tinyQ8_0 → const WhisperModel
-
values
→ const List<
WhisperModel>